==> rocSPARSE-7.0.2.tar.gz: rocSPARSE-rocm-7.0.2/clients/include/rocsparse_clients_routine_trace.hpp <==
/*! \file */
/* ************************************************************************
 * Copyright (C) 2025 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * ************************************************************************ */

#pragma once

#if defined(ROCSPARSE_CLIENTS_WITH_ROCTX)
#include <roctracer/roctx.h>
#endif

namespace rocsparse_clients
{
#if defined(ROCSPARSE_CLIENTS_WITH_ROCTX)
    class internal_roctx
    {
    public:
        internal_roctx(const char* name)
        {
            roctxRangePush(name);
        }

        ~internal_roctx()
        {
            roctxRangePop();
        }
    };
#define ROCSPARSE_CLIENTS_ROCTX_TRACE rocsparse_clients::internal_roctx roctx(__FUNCTION__);
#else
#define ROCSPARSE_CLIENTS_ROCTX_TRACE
#endif

#define ROCSPARSE_CLIENTS_ROUTINE_TRACE ROCSPARSE_CLIENTS_ROCTX_TRACE
}

==> rocSPARSE-7.1.0.tar.gz: rocSPARSE-rocm-7.1.0/clients/include/rocsparse_clients_routine_trace.hpp <==
/*! \file */
/* ************************************************************************
 * Copyright (C) 2025 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * ************************************************************************ */

#pragma once

#if defined(ROCSPARSE_CLIENTS_WITH_ROCTX)
#include <roctracer/roctx.h>
#endif

namespace rocsparse_clients
{
#if defined(ROCSPARSE_CLIENTS_WITH_ROCTX)
    class internal_roctx
    {
    public:
        internal_roctx(const char* name)
        {
            roctxRangePush(name);
        }

        ~internal_roctx()
        {
            roctxRangePop();
        }
    };
#define ROCSPARSE_CLIENTS_ROCTX_TRACE rocsparse_clients::internal_roctx roctx(__FUNCTION__)
#else
#define ROCSPARSE_CLIENTS_ROCTX_TRACE
#endif

#define ROCSPARSE_CLIENTS_ROUTINE_TRACE ROCSPARSE_CLIENTS_ROCTX_TRACE
}
